<?php 

/* --- based on the Basic Theme: http://drupal.org/project/basic --- */

/**
 * This function creates the body classes that are relative to each page
 *	
 * @param $vars
 *  A sequential array of variables to pass to the theme template.
 * @param $hook
 *  The name of the theme function being called ("page" in this case.)
 */
function bigdaddy_preprocess_page(&$vars, $hook) {

  $body_classes = array($vars['body_classes']);
  if (theme_get_setting('bigdaddy_wireframes')) {
    $body_classes[] = 'wireframes'; // Optionally add the wireframes style.
  }
  if (theme_get_setting('bigdaddy_grids')) {
    $body_classes[] = 'grids'; // Optionally add the grids background.
  }
  
  // Set up layout variable.
  $vars['layout'] = '';

  if (!empty($vars['sidebar_first'])) {
    $vars['layout'] = 'sidebar-first';
  }
  if (!empty($vars['sidebar_second'])) {
    $vars['layout'] = ($vars['layout'] == 'sidebar-first') ? 'both-sidebars' : 'sidebar-second';
  }
  
  $body_classes[] = $vars['layout'];
  
  $vars['body_classes'] = implode(' ', $body_classes); // Concatenate with spaces
  
}

/**
 * This function creates the NODES classes, like 'node-unpublished' for nodes
 * that are not published, or 'node-mine' for node posted by the connected user...
 *	
 * @param $vars
 *  A sequential array of variables to pass to the theme template.
 * @param $hook
 *  The name of the theme function being called ("node" in this case.)
 */
function bigdaddy_preprocess_node(&$vars, $hook) {
  
  // Special classes for nodes
  $classes = array('node');
  if ($vars['sticky']) {
    $classes[] = 'sticky';
  }
  // support for Skinr Module
  if (module_exists('skinr') && $vars['skinr'] != '') {
    $classes[] = $vars['skinr'];
  }
  
  if ($vars['teaser']) {
    $classes[] = 'node-teaser'; // Node is displayed as teaser.
  }
  
  // Class for node type: "node-type-page", "node-type-story", "node-type-my-custom-type", etc.
  $classes[] = 'node-type-' . $vars['type'];
  $vars['node_classes'] = implode(' ', $classes); // Concatenate with spaces
}


/**
 * This function create the EDIT LINKS for blocks and menus blocks.
 * When overing a block (except in IE6), some links appear to edit
 * or configure the block. You can then edit the block, and once you are
 * done, brought back to the first page.
 *
 * @param $vars
 *  A sequential array of variables to pass to the theme template.
 * @param $hook
 *  The name of the theme function being called bigdaddy
 */
function bigdaddy_preprocess_block(&$vars, $hook) {

  $block = $vars['block'];
  
  // special block classes
  $classes = array('block');
  $classes[] = 'block-' . $vars['block']->module;
  $classes[] = 'clearfix';
    
  // support for Skinr Module
  if (module_exists('skinr') && $vars['skinr'] != '') {
    $classes[] = $vars['skinr'];
  }
    
  $vars['block_classes'] = implode(' ', $classes); // Concatenate with spaces
  
  // Add Block Editing 
  if (theme_get_setting('bigdaddy_block_editing') && user_access('administer blocks')) {
    // Display 'edit block' for custom blocks.
    if ($block->module == 'block') {
      $vars['edit_block'] = l(t('edit block'), 'admin/build/block/configure/block/' . $block->delta, array('attributes'=>array('class'=>'block-edit', 'title'=>'edit '.$block->subject.' block'), 'query'=>drupal_get_destination()));
    }
    // Display 'edit menu' for Menu blocks.
    if ($block->module == 'menu' && user_access('administer menu')) {
      $menu_name = ($block->module == 'user') ? 'navigation' : $block->delta;
      $vars['edit_block'] = l(t('edit menu'), 'admin/build/menu-customize/' . $menu_name, array('attributes'=>array('class'=>'block-edit', 'title'=>'edit '.$menu_name.' block'), 'query'=>drupal_get_destination()));
    }
    // Display 'edit menu' for Menu block blocks.
    elseif ($block->module == 'menu_block' && user_access('administer menu')) {
      list($menu_name, ) = split(':', variable_get("menu_block_{$block->delta}_parent", 'navigation:0'));
      $vars['edit_block'] = l(t('edit menu'), 'admin/build/menu-customize/' . $menu_name, array('attributes'=>array('class'=>'block-edit', 'title'=>'edit '.$menu_name.' block'), 'query'=>drupal_get_destination()));
    }
  }  
  
}

// Add Stylesheet for Grid System OR Wireframes
if ((theme_get_setting('bigdaddy_grids') || theme_get_settings('bigdaddy_wireframes') || theme_get_setting('bigdaddy_block_editing')) && user_is_logged_in()) {
  drupal_add_css( drupal_get_path('theme', 'bigdaddy') .'/styles/theme-settings.css', 'theme', 'screen');
}