<?php

/**
* Implementation of THEMEHOOK_settings() function.
*
* @param $saved_settings
*  array An array of saved settings for this theme.
* @return
*  array A form array.
*/

function bigdaddy_settings($saved_settings) {

  // Get the default values from the .info file.
  $defaults = bigdaddy_theme_get_default_settings('bigdaddy');

  // Merge the saved variables and their default values.
  $settings = array_merge($defaults, $saved_settings);
  
  // Create the form widgets using Forms API
  $form['bigdaddy_grids'] = array(
    '#type' => 'checkbox',
    '#title' => t('Activate 960 Grid background'),
    '#default_value' => $settings['bigdaddy_grids'],
    '#description'   => t('Background image grid + pixel ruler + column divisions for 960px-width layout, all in one, by <a href="!link">Cameron Moll</a>', array('!link' => 'http://www.cameronmoll.com/archives/2006/12/gridding_the_960/')),
    '#prefix'        => '<strong>' . t('Information architecture:') . '</strong>',
  );
  $form['bigdaddy_wireframes'] = array(
    '#type' => 'checkbox',
    '#title' => t('Activate Wireframes'),
    '#default_value' => $settings['bigdaddy_wireframes'],
    '#description'   => t('<a href="!link">Wireframes</a> are useful when prototyping a website.', array('!link' => 'http://www.boxesandarrows.com/view/html_wireframes_and_prototypes_all_gain_and_no_pain')),
  );
  $form['bigdaddy_block_editing'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show block editing on hover'),
    '#default_value' => $settings['bigdaddy_block_editing'],
    '#description'   => t('When hovering over a block, privileged users will see block editing links.'),
    '#prefix'        => '<strong>' . t('Block editing:') . '</strong>',
  );

  // Return the additional form widgets
  return $form; 

}

function bigdaddy_theme_get_default_settings($theme) {
  $themes = list_themes();

  // Get the default values from the .info file.
  $defaults = !empty($themes[$theme]->info['settings']) ? $themes[$theme]->info['settings'] : array();

  if (!empty($defaults)) {
    // Get the theme settings saved in the database.
    $settings = theme_get_settings($theme);
    // Don't save the toggle_node_info_ variables.
    if (module_exists('node')) {
      foreach (node_get_types() as $type => $name) {
        unset($settings['toggle_node_info_' . $type]);
      }
    }
    // Save default theme settings.
    variable_set(
      str_replace('/', '_', 'theme_' . $theme . '_settings'),
      array_merge($defaults, $settings)
    );
    // If the active theme has been loaded, force refresh of Drupal internals.
    if (!empty($GLOBALS['theme_key'])) {
      theme_get_setting('', TRUE);
    }
  }

  // Return the default settings.
  return $defaults;
}